@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2020 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -25,6 +25,7 @@
 include('./include/auth.php');
 include_once('./lib/import.php');
 include_once('./lib/poller.php');
+include_once('./lib/template.php');
 include_once('./lib/utility.php');
 
 /* set default action */
@@ -97,7 +98,8 @@ function form_save() {
 		if ($debug_data !== false && cacti_sizeof($debug_data)) {
 			$_SESSION['import_debug_info'] = $debug_data;
 		} else {
-			raise_message(15);
+			cacti_log("ERROR: Import or Preview failed!", false, 'IMPORT');
+			raise_message('import_error', __('The Template Import Failed.  See the cacti.log for more details.', MESSAGE_LEVEL_ERROR));
 		}
 
 		header('Location: templates_import.php?preview=' . $preview_only);
